
Changelog
=========

1.1.1 (2021-11-19)
------------------

* Added postal address error handling

1.1.0 (2021-04-21)
------------------

* Minor fixes
* Error class 'UnparableApiResponse' was renamed to 'UnparsableApiResponseError'


1.0.0 (2021-04-12)
------------------

* First release